# coding: utf-8

"""
    Video Conferencing Extension

    These APIs allow you to specify URLs that can be used to interact with a video conferencing application, to allow HubSpot to add video conference links to meeting requests with contacts.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.extensions.videoconferencing.api_client import ApiClient
from hubspot.crm.extensions.videoconferencing.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class SettingsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, app_id, **kwargs):  # noqa: E501
        """Delete settings  # noqa: E501

        Deletes the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(app_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, app_id, **kwargs):  # noqa: E501
        """Delete settings  # noqa: E501

        Deletes the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/extensions/videoconferencing/settings/{appId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, app_id, **kwargs):  # noqa: E501
        """Get settings  # noqa: E501

        Return the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ExternalSettings
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(app_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, app_id, **kwargs):  # noqa: E501
        """Get settings  # noqa: E501

        Return the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ExternalSettings, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "ExternalSettings",
        }

        return self.api_client.call_api(
            "/crm/v3/extensions/videoconferencing/settings/{appId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def replace(self, app_id, external_settings, **kwargs):  # noqa: E501
        """Update settings  # noqa: E501

        Updates the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace(app_id, external_settings, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param external_settings: (required)
        :type external_settings: ExternalSettings
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ExternalSettings
        """
        kwargs["_return_http_data_only"] = True
        return self.replace_with_http_info(app_id, external_settings, **kwargs)  # noqa: E501

    def replace_with_http_info(self, app_id, external_settings, **kwargs):  # noqa: E501
        """Update settings  # noqa: E501

        Updates the settings for a video conference application with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_with_http_info(app_id, external_settings, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the video conference application. This is the identifier of the application created in your HubSpot developer portal. (required)
        :type app_id: int
        :param external_settings: (required)
        :type external_settings: ExternalSettings
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ExternalSettings, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id", "external_settings"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method replace" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `replace`")  # noqa: E501
        # verify the required parameter 'external_settings' is set
        if self.api_client.client_side_validation and local_var_params.get("external_settings") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `external_settings` when calling `replace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "external_settings" in local_var_params:
            body_params = local_var_params["external_settings"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "ExternalSettings",
        }

        return self.api_client.call_api(
            "/crm/v3/extensions/videoconferencing/settings/{appId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class FileStat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"file": "File", "folder": "Folder"}

    attribute_map = {"file": "file", "folder": "folder"}

    def __init__(self, file=None, folder=None, local_vars_configuration=None):  # noqa: E501
        """FileStat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._folder = None
        self.discriminator = None

        if file is not None:
            self.file = file
        if folder is not None:
            self.folder = folder

    @property
    def file(self):
        """Gets the file of this FileStat.  # noqa: E501


        :return: The file of this FileStat.  # noqa: E501
        :rtype: File
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this FileStat.


        :param file: The file of this FileStat.  # noqa: E501
        :type file: File
        """

        self._file = file

    @property
    def folder(self):
        """Gets the folder of this FileStat.  # noqa: E501


        :return: The folder of this FileStat.  # noqa: E501
        :rtype: Folder
        """
        return self._folder

    @folder.setter
    def folder(self, folder):
        """Sets the folder of this FileStat.


        :param folder: The folder of this FileStat.  # noqa: E501
        :type folder: Folder
        """

        self._folder = folder

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileStat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileStat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicSurveyMonkeyValueFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "value_comparison": "PublicSurveyMonkeyValueFilterValueComparison",
        "survey_id": "str",
        "survey_question": "str",
        "filter_type": "str",
        "survey_answer_row_id": "str",
        "survey_answer_col_id": "str",
        "operator": "str",
    }

    attribute_map = {
        "value_comparison": "valueComparison",
        "survey_id": "surveyId",
        "survey_question": "surveyQuestion",
        "filter_type": "filterType",
        "survey_answer_row_id": "surveyAnswerRowId",
        "survey_answer_col_id": "surveyAnswerColId",
        "operator": "operator",
    }

    def __init__(
        self,
        value_comparison=None,
        survey_id=None,
        survey_question=None,
        filter_type="SURVEY_MONKEY_VALUE",
        survey_answer_row_id=None,
        survey_answer_col_id=None,
        operator=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicSurveyMonkeyValueFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._value_comparison = None
        self._survey_id = None
        self._survey_question = None
        self._filter_type = None
        self._survey_answer_row_id = None
        self._survey_answer_col_id = None
        self._operator = None
        self.discriminator = None

        self.value_comparison = value_comparison
        self.survey_id = survey_id
        self.survey_question = survey_question
        self.filter_type = filter_type
        if survey_answer_row_id is not None:
            self.survey_answer_row_id = survey_answer_row_id
        if survey_answer_col_id is not None:
            self.survey_answer_col_id = survey_answer_col_id
        self.operator = operator

    @property
    def value_comparison(self):
        """Gets the value_comparison of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The value_comparison of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: PublicSurveyMonkeyValueFilterValueComparison
        """
        return self._value_comparison

    @value_comparison.setter
    def value_comparison(self, value_comparison):
        """Sets the value_comparison of this PublicSurveyMonkeyValueFilter.


        :param value_comparison: The value_comparison of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type value_comparison: PublicSurveyMonkeyValueFilterValueComparison
        """
        if self.local_vars_configuration.client_side_validation and value_comparison is None:  # noqa: E501
            raise ValueError("Invalid value for `value_comparison`, must not be `None`")  # noqa: E501

        self._value_comparison = value_comparison

    @property
    def survey_id(self):
        """Gets the survey_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The survey_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._survey_id

    @survey_id.setter
    def survey_id(self, survey_id):
        """Sets the survey_id of this PublicSurveyMonkeyValueFilter.


        :param survey_id: The survey_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type survey_id: str
        """
        if self.local_vars_configuration.client_side_validation and survey_id is None:  # noqa: E501
            raise ValueError("Invalid value for `survey_id`, must not be `None`")  # noqa: E501

        self._survey_id = survey_id

    @property
    def survey_question(self):
        """Gets the survey_question of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The survey_question of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._survey_question

    @survey_question.setter
    def survey_question(self, survey_question):
        """Sets the survey_question of this PublicSurveyMonkeyValueFilter.


        :param survey_question: The survey_question of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type survey_question: str
        """
        if self.local_vars_configuration.client_side_validation and survey_question is None:  # noqa: E501
            raise ValueError("Invalid value for `survey_question`, must not be `None`")  # noqa: E501

        self._survey_question = survey_question

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The filter_type of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicSurveyMonkeyValueFilter.


        :param filter_type: The filter_type of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["SURVEY_MONKEY_VALUE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def survey_answer_row_id(self):
        """Gets the survey_answer_row_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The survey_answer_row_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._survey_answer_row_id

    @survey_answer_row_id.setter
    def survey_answer_row_id(self, survey_answer_row_id):
        """Sets the survey_answer_row_id of this PublicSurveyMonkeyValueFilter.


        :param survey_answer_row_id: The survey_answer_row_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type survey_answer_row_id: str
        """

        self._survey_answer_row_id = survey_answer_row_id

    @property
    def survey_answer_col_id(self):
        """Gets the survey_answer_col_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The survey_answer_col_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._survey_answer_col_id

    @survey_answer_col_id.setter
    def survey_answer_col_id(self, survey_answer_col_id):
        """Sets the survey_answer_col_id of this PublicSurveyMonkeyValueFilter.


        :param survey_answer_col_id: The survey_answer_col_id of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type survey_answer_col_id: str
        """

        self._survey_answer_col_id = survey_answer_col_id

    @property
    def operator(self):
        """Gets the operator of this PublicSurveyMonkeyValueFilter.  # noqa: E501


        :return: The operator of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicSurveyMonkeyValueFilter.


        :param operator: The operator of this PublicSurveyMonkeyValueFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicSurveyMonkeyValueFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicSurveyMonkeyValueFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import io
import json
import logging
import re
import ssl

# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import urlencode
import urllib3

from hubspot.crm.objects.exceptions import ApiException, UnauthorizedException, ForbiddenException, NotFoundException, ServiceException, ApiValueError


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):
    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """Returns a dictionary of the response headers."""
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):
    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args["assert_hostname"] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args["retries"] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args["socket_options"] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=configuration.ssl_ca_cert,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size, maxsize=maxsize, cert_reqs=cert_reqs, ca_certs=configuration.ssl_ca_cert, cert_file=configuration.cert_file, key_file=configuration.key_file, **addition_pool_args
            )

    def request(self, method, url, query_params=None, headers=None, body=None, post_params=None, _preload_content=True, _request_timeout=None):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ["GET", "HEAD", "DELETE", "POST", "PUT", "PATCH", "OPTIONS"]

        if post_params and body:
            raise ApiValueError("body parameter cannot be used with post_params parameter.")

        post_params = post_params or {}
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, six.integer_types + (float,)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=_request_timeout)
            elif isinstance(_request_timeout, tuple) and len(_request_timeout) == 2:
                timeout = urllib3.Timeout(connect=_request_timeout[0], read=_request_timeout[1])

        if "Content-Type" not in headers:
            headers["Content-Type"] = "application/json"

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ["POST", "PUT", "PATCH", "OPTIONS", "DELETE"]:
                if query_params:
                    url += "?" + urlencode(query_params)
                if re.search("json", headers["Content-Type"], re.IGNORECASE):
                    request_body = None
                    if body is not None:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(method, url, body=request_body, preload_content=_preload_content, timeout=timeout, headers=headers)
                elif headers["Content-Type"] == "application/x-www-form-urlencoded":  # noqa: E501
                    r = self.pool_manager.request(method, url, fields=post_params, encode_multipart=False, preload_content=_preload_content, timeout=timeout, headers=headers)
                elif headers["Content-Type"] == "multipart/form-data":
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers["Content-Type"]
                    r = self.pool_manager.request(method, url, fields=post_params, encode_multipart=True, preload_content=_preload_content, timeout=timeout, headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(method, url, body=request_body, preload_content=_preload_content, timeout=timeout, headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url, fields=query_params, preload_content=_preload_content, timeout=timeout, headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if _preload_content:
            r = RESTResponse(r)

            # log response body
            logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            if r.status == 401:
                raise UnauthorizedException(http_resp=r)

            if r.status == 403:
                raise ForbiddenException(http_resp=r)

            if r.status == 404:
                raise NotFoundException(http_resp=r)

            if 500 <= r.status <= 599:
                raise ServiceException(http_resp=r)

            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("GET", url, headers=headers, _preload_content=_preload_content, _request_timeout=_request_timeout, query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("HEAD", url, headers=headers, _preload_content=_preload_content, _request_timeout=_request_timeout, query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("OPTIONS", url, headers=headers, query_params=query_params, post_params=post_params, _preload_content=_preload_content, _request_timeout=_request_timeout, body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url, headers=headers, query_params=query_params, _preload_content=_preload_content, _request_timeout=_request_timeout, body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("POST", url, headers=headers, query_params=query_params, post_params=post_params, _preload_content=_preload_content, _request_timeout=_request_timeout, body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("PUT", url, headers=headers, query_params=query_params, post_params=post_params, _preload_content=_preload_content, _request_timeout=_request_timeout, body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("PATCH", url, headers=headers, query_params=query_params, post_params=post_params, _preload_content=_preload_content, _request_timeout=_request_timeout, body=body)



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class MarketingEventEmailSubscriber(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"contact_properties": "dict[str, str]", "properties": "dict[str, str]", "email": "str", "interaction_date_time": "int"}

    attribute_map = {"contact_properties": "contactProperties", "properties": "properties", "email": "email", "interaction_date_time": "interactionDateTime"}

    def __init__(self, contact_properties=None, properties=None, email=None, interaction_date_time=None, local_vars_configuration=None):  # noqa: E501
        """MarketingEventEmailSubscriber - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._contact_properties = None
        self._properties = None
        self._email = None
        self._interaction_date_time = None
        self.discriminator = None

        if contact_properties is not None:
            self.contact_properties = contact_properties
        if properties is not None:
            self.properties = properties
        self.email = email
        self.interaction_date_time = interaction_date_time

    @property
    def contact_properties(self):
        """Gets the contact_properties of this MarketingEventEmailSubscriber.  # noqa: E501


        :return: The contact_properties of this MarketingEventEmailSubscriber.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._contact_properties

    @contact_properties.setter
    def contact_properties(self, contact_properties):
        """Sets the contact_properties of this MarketingEventEmailSubscriber.


        :param contact_properties: The contact_properties of this MarketingEventEmailSubscriber.  # noqa: E501
        :type contact_properties: dict[str, str]
        """

        self._contact_properties = contact_properties

    @property
    def properties(self):
        """Gets the properties of this MarketingEventEmailSubscriber.  # noqa: E501


        :return: The properties of this MarketingEventEmailSubscriber.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this MarketingEventEmailSubscriber.


        :param properties: The properties of this MarketingEventEmailSubscriber.  # noqa: E501
        :type properties: dict[str, str]
        """

        self._properties = properties

    @property
    def email(self):
        """Gets the email of this MarketingEventEmailSubscriber.  # noqa: E501

        The email address of the contact in HubSpot to associate with the event.  # noqa: E501

        :return: The email of this MarketingEventEmailSubscriber.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this MarketingEventEmailSubscriber.

        The email address of the contact in HubSpot to associate with the event.  # noqa: E501

        :param email: The email of this MarketingEventEmailSubscriber.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def interaction_date_time(self):
        """Gets the interaction_date_time of this MarketingEventEmailSubscriber.  # noqa: E501

        Timestamp in milliseconds at which the contact subscribed to the event.  # noqa: E501

        :return: The interaction_date_time of this MarketingEventEmailSubscriber.  # noqa: E501
        :rtype: int
        """
        return self._interaction_date_time

    @interaction_date_time.setter
    def interaction_date_time(self, interaction_date_time):
        """Sets the interaction_date_time of this MarketingEventEmailSubscriber.

        Timestamp in milliseconds at which the contact subscribed to the event.  # noqa: E501

        :param interaction_date_time: The interaction_date_time of this MarketingEventEmailSubscriber.  # noqa: E501
        :type interaction_date_time: int
        """
        if self.local_vars_configuration.client_side_validation and interaction_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `interaction_date_time`, must not be `None`")  # noqa: E501

        self._interaction_date_time = interaction_date_time

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarketingEventEmailSubscriber):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarketingEventEmailSubscriber):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.cards.configuration import Configuration


class IntegratorObjectResultActionsInner(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "property_names_included": "list[str]",
        "confirmation": "ActionConfirmationBody",
        "label": "str",
        "type": "str",
        "http_method": "str",
        "url": "str",
        "width": "int",
        "height": "int",
    }

    attribute_map = {
        "property_names_included": "propertyNamesIncluded",
        "confirmation": "confirmation",
        "label": "label",
        "type": "type",
        "http_method": "httpMethod",
        "url": "url",
        "width": "width",
        "height": "height",
    }

    def __init__(self, property_names_included=None, confirmation=None, label=None, type="IFRAME", http_method=None, url=None, width=None, height=None, local_vars_configuration=None):  # noqa: E501
        """IntegratorObjectResultActionsInner - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._property_names_included = None
        self._confirmation = None
        self._label = None
        self._type = None
        self._http_method = None
        self._url = None
        self._width = None
        self._height = None
        self.discriminator = None

        self.property_names_included = property_names_included
        if confirmation is not None:
            self.confirmation = confirmation
        if label is not None:
            self.label = label
        self.type = type
        self.http_method = http_method
        self.url = url
        self.width = width
        self.height = height

    @property
    def property_names_included(self):
        """Gets the property_names_included of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The property_names_included of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: list[str]
        """
        return self._property_names_included

    @property_names_included.setter
    def property_names_included(self, property_names_included):
        """Sets the property_names_included of this IntegratorObjectResultActionsInner.


        :param property_names_included: The property_names_included of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type property_names_included: list[str]
        """
        if self.local_vars_configuration.client_side_validation and property_names_included is None:  # noqa: E501
            raise ValueError("Invalid value for `property_names_included`, must not be `None`")  # noqa: E501

        self._property_names_included = property_names_included

    @property
    def confirmation(self):
        """Gets the confirmation of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The confirmation of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: ActionConfirmationBody
        """
        return self._confirmation

    @confirmation.setter
    def confirmation(self, confirmation):
        """Sets the confirmation of this IntegratorObjectResultActionsInner.


        :param confirmation: The confirmation of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type confirmation: ActionConfirmationBody
        """

        self._confirmation = confirmation

    @property
    def label(self):
        """Gets the label of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The label of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this IntegratorObjectResultActionsInner.


        :param label: The label of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type label: str
        """

        self._label = label

    @property
    def type(self):
        """Gets the type of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The type of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IntegratorObjectResultActionsInner.


        :param type: The type of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["IFRAME"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def http_method(self):
        """Gets the http_method of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The http_method of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: str
        """
        return self._http_method

    @http_method.setter
    def http_method(self, http_method):
        """Sets the http_method of this IntegratorObjectResultActionsInner.


        :param http_method: The http_method of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type http_method: str
        """
        if self.local_vars_configuration.client_side_validation and http_method is None:  # noqa: E501
            raise ValueError("Invalid value for `http_method`, must not be `None`")  # noqa: E501
        allowed_values = ["CONNECT", "DELETE", "GET", "HEAD", "OPTIONS", "PATCH", "POST", "PUT", "TRACE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and http_method not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `http_method` ({0}), must be one of {1}".format(http_method, allowed_values))  # noqa: E501

        self._http_method = http_method

    @property
    def url(self):
        """Gets the url of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The url of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this IntegratorObjectResultActionsInner.


        :param url: The url of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def width(self):
        """Gets the width of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The width of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this IntegratorObjectResultActionsInner.


        :param width: The width of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type width: int
        """
        if self.local_vars_configuration.client_side_validation and width is None:  # noqa: E501
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501

        self._width = width

    @property
    def height(self):
        """Gets the height of this IntegratorObjectResultActionsInner.  # noqa: E501


        :return: The height of this IntegratorObjectResultActionsInner.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this IntegratorObjectResultActionsInner.


        :param height: The height of this IntegratorObjectResultActionsInner.  # noqa: E501
        :type height: int
        """
        if self.local_vars_configuration.client_side_validation and height is None:  # noqa: E501
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegratorObjectResultActionsInner):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegratorObjectResultActionsInner):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.hubdb.configuration import Configuration


class HubDbTableRowV3BatchUpdateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"path": "str", "child_table_id": "int", "values": "dict[str, object]", "name": "str", "id": "str", "display_index": "int"}

    attribute_map = {"path": "path", "child_table_id": "childTableId", "values": "values", "name": "name", "id": "id", "display_index": "displayIndex"}

    def __init__(self, path=None, child_table_id=None, values=None, name=None, id=None, display_index=None, local_vars_configuration=None):  # noqa: E501
        """HubDbTableRowV3BatchUpdateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._path = None
        self._child_table_id = None
        self._values = None
        self._name = None
        self._id = None
        self._display_index = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if child_table_id is not None:
            self.child_table_id = child_table_id
        self.values = values
        if name is not None:
            self.name = name
        self.id = id
        if display_index is not None:
            self.display_index = display_index

    @property
    def path(self):
        """Gets the path of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501

        Specifies the value for `hs_path` column, which will be used as slug in the dynamic pages  # noqa: E501

        :return: The path of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this HubDbTableRowV3BatchUpdateRequest.

        Specifies the value for `hs_path` column, which will be used as slug in the dynamic pages  # noqa: E501

        :param path: The path of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def child_table_id(self):
        """Gets the child_table_id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501

        Specifies the value for the column child table id  # noqa: E501

        :return: The child_table_id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._child_table_id

    @child_table_id.setter
    def child_table_id(self, child_table_id):
        """Sets the child_table_id of this HubDbTableRowV3BatchUpdateRequest.

        Specifies the value for the column child table id  # noqa: E501

        :param child_table_id: The child_table_id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type child_table_id: int
        """

        self._child_table_id = child_table_id

    @property
    def values(self):
        """Gets the values of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501

        List of key value pairs with the column name and column value  # noqa: E501

        :return: The values of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this HubDbTableRowV3BatchUpdateRequest.

        List of key value pairs with the column name and column value  # noqa: E501

        :param values: The values of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type values: dict[str, object]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values

    @property
    def name(self):
        """Gets the name of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501

        Specifies the value for `hs_name` column, which will be used as title in the dynamic pages  # noqa: E501

        :return: The name of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubDbTableRowV3BatchUpdateRequest.

        Specifies the value for `hs_name` column, which will be used as title in the dynamic pages  # noqa: E501

        :param name: The name of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501

        The id of the table row  # noqa: E501

        :return: The id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HubDbTableRowV3BatchUpdateRequest.

        The id of the table row  # noqa: E501

        :param id: The id of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def display_index(self):
        """Gets the display_index of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501


        :return: The display_index of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._display_index

    @display_index.setter
    def display_index(self, display_index):
        """Sets the display_index of this HubDbTableRowV3BatchUpdateRequest.


        :param display_index: The display_index of this HubDbTableRowV3BatchUpdateRequest.  # noqa: E501
        :type display_index: int
        """

        self._display_index = display_index

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubDbTableRowV3BatchUpdateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubDbTableRowV3BatchUpdateRequest):
            return True

        return self.to_dict() != other.to_dict()
